@@ -40,7 +40,7 @@ class CampaignTestCase(unittest.TestCase):
     self.assertEquals(summary.Unsubscribed, 0)
     self.assertEquals(summary.Bounced, 0)
     self.assertEquals(summary.UniqueOpened, 5)
-    self.assertEquals(summary.WebVersionURL, "http://clientone.createsend.com/t/ViewEmail/r/3A433FC72FFE3B8B/C67FD2F38AC4859C/")
+    self.assertEquals(summary.WebVersionURL, "http://createsend.com/t/r-3A433FC72FFE3B8B")
 
   def test_lists_and_segments(self):
     self.campaign.stub_request("campaigns/%s/listsandsegments.json" % self.campaign_id, "campaign_listsandsegments.json")
@@ -120,8 +120,9 @@ class CampaignTestCase(unittest.TestCase):
     self.assertEquals(unsubscribes.NumberOfPages, 1)
 
   def test_bounces(self):
-    self.campaign.stub_request("campaigns/%s/bounces.json?orderfield=date&page=1&pagesize=1000&orderdirection=asc" % self.campaign_id, "campaign_bounces.json")
-    bounces = self.campaign.bounces()
+    min_date = "2010-01-01"
+    self.campaign.stub_request("campaigns/%s/bounces.json?date=%s&orderfield=date&page=1&pagesize=1000&orderdirection=asc" % (self.campaign_id, urllib.quote(min_date, '')), "campaign_bounces.json")
+    bounces = self.campaign.bounces(min_date)
     self.assertEquals(len(bounces.Results), 2)
     self.assertEquals(bounces.Results[0].EmailAddress, "asdf@softbouncemyemail.com")
     self.assertEquals(bounces.Results[0].ListID, "654523a5855b4a440bae3fb295641546")
